Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type App ¶
App manages the application settings and configuration
type Config ¶
type Config struct {
Database struct {
Host string
Port int
User string
Password string
Sslmode string
Dbname string
MigrateTable string `yaml:"migrateTable"`
}
}
Config config to run gatherfi
func GetConfig ¶
GetConfig allows us to retrieve the config easier
type Database ¶
type Database struct {
// contains filtered or unexported fields
}
Database structure for handling database operations
func GetDatabase ¶
GetDatabase allows us to retrieve the database easier
func NewDatabase ¶
NewDatabase creates a Database object and connects to database
func (*Database) Connect ¶
Connect will open the connection and attempt to contact the server
Source Files
¶
- app.go
- config.go
- database.go
- server.go
Click to show internal directories.
Click to hide internal directories.